/*
 * Copyright 2005-2007 Noelios Consulting.
 * 
 * The contents of this file are subject to the terms of the Common Development
 * and Distribution License (the "License"). You may not use this file except in
 * compliance with the License.
 * 
 * You can obtain a copy of the license at
 * http://www.opensource.org/licenses/cddl1.txt See the License for the specific
 * language governing permissions and limitations under the License.
 * 
 * When distributing Covered Code, include this CDDL HEADER in each file and
 * include the License file at http://www.opensource.org/licenses/cddl1.txt If
 * applicable, add the following below this CDDL HEADER, with the fields
 * enclosed by brackets "[]" replaced with your own identifying information:
 * Portions Copyright [yyyy] [name of copyright owner]
 */

package com.blinksale.domain;

import java.util.List;

import javax.rws.ResourceRef;

/**
 * BlinkSale user account.
 * 
 * @author Jerome Louvel (contact@noelios.com)
 */
public class Account {

    private String id;

    private List<Invoice> invoices;

    private List<Payment> payments;

    private List<Delivery> deliveries;

    private List<Client> clients;

    public Client getClientById(String id) {
        for (Client client : getClients()) {
            if (client.getId().equals(id)) {
                return client;
            }
        }
        return null;
    }

    public List<Client> getClients() {
        return clients;
    }

    public List<Delivery> getDeliveries() {
        return deliveries;
    }

    public String getId() {
        return id;
    }

    @ResourceRef("/invoices")
    public List<Invoice> getInvoices() {
        return invoices;
    }

    public List<Payment> getPayments() {
        return payments;
    }

    public float getTotalPaid() {
        float total = 0.0F;

        for (Payment payment : getPayments()) {
            total += payment.getAmount();
        }

        return total;
    }

    public void setId(String id) {
        this.id = id;
    }
}
